export default {
  name: 'homepage',
  type: 'document',
  title: 'Edit international homepage',
  fields: [
    {
      name: 'main_image',
      title: 'Main image',
      description: 'The large image showing up below the header',
      type: 'image',
      options: {
        hotspot: true,
      },
      fields: [
        {
          name: 'alt',
          title: 'Alternative text',
          description: 'The text that will be shown if the image does not load',
          type: 'string',
        },
      ],
    },
    {
      name: 'title_detectors',
      title: 'Title for the detectors',
      description: 'The title with bold text above the detectors row',
      type: 'string',
    },
    {
      name: 'subtitle_detectors',
      title: 'Subtitle for the detectors',
      description: 'The subtitle with semibold text above the EBSD detectors row',
      type: 'string',
    },
    {
      name: 'images_detectors',
      title: 'Images for the detectors row',
      description: 'The images showing up in the detectors row',
      type: 'array',
      of: [
        {
          name: 'image',
          title: 'Image',
          type: 'image',
          options: {
            hotspot: true,
          },
          fields: [
            {
              name: 'slug',
              title: 'Slug',
              description:
                'The shorthand name of this detector, used for this specific detector in the detectors category page (used to redirect to the correct page when pressed on)',
              type: 'string',
              validation: (Rule: {required: () => any}) => Rule.required(),
            },
            {
              name: 'number',
              title: 'Number in line',
              description: 'The number in the sequence of detectors this detector should be shown',
              type: 'number',
              validation: (Rule: {required: () => any}) => Rule.required().min(1),
            },
            {
              name: 'img_description',
              title: 'Image description',
              description: 'The text under the images in the detectors row',
              type: 'string',
            },
            {
              name: 'alt',
              title: 'Alternative text',
              description:
                'Text that appears if image doesnt load (you can set this to the name of the detector on this image)',
              type: 'string',
            },
          ],
        },
      ],
      options: {
        layout: 'grid',
      },
    },
    {
      name: 'title_services',
      title: 'Title for the services row',
      description: 'The title with bold text above the services row',
      type: 'string',
    },
    {
      name: 'subtitle_services',
      title: 'Subtitle for the services row',
      description: 'The subtitle with semibold text above the services row',
      type: 'string',
    },
    {
      name: 'images_services',
      title: 'Images for the services row',
      description: 'The images showing up in the services row',
      type: 'array',
      of: [
        {
          name: 'image',
          title: 'Image',
          type: 'image',
          options: {
            hotspot: true,
          },
          fields: [
            {
              name: 'slug',
              title: 'Slug',
              description:
                'The shorthand name of the service, used for this specific service in the services category page (used to redirect to the correct page when pressed on)',
              type: 'string',
              validation: (Rule: {required: () => any}) => Rule.required(),
            },
            {
              name: 'number',
              title: 'Number in line',
              description: 'The number in the sequence of services this service should be shown',
              type: 'number',
              validation: (Rule: {required: () => any}) => Rule.required().min(1),
            },
            {
              name: 'img_description',
              title: 'Image description',
              description: 'The text under the images in the services row',
              type: 'string',
            },
            {
              name: 'alt',
              title: 'Alternative text',
              description:
                'Text that appears if image doesnt load (you can set this to the name of the service on this image)',
              type: 'string',
            },
          ],
        },
      ],
      options: {
        layout: 'grid',
      },
    },

    {
      name: 'title_applications',
      title: 'Title for the applications row',
      description: 'The bold title above the applications row',
      type: 'string',
    },
    {
      name: 'subtitle_applications',
      title: 'Subtitle for the applications row',
      description: 'The semibold text above the applications row',
      type: 'string',
    },
    {
      name: 'images_applications',
      title: 'Images for the applications row',
      description: 'The images showing up in the applications row',
      type: 'array',
      of: [
        {
          name: 'image',
          title: 'Image',
          type: 'image',
          options: {
            hotspot: true,
          },
          fields: [
            {
              name: 'slug',
              title: 'Slug',
              description:
                'The shorthand name of the application, used for this specific application in the applications category page (used to redirect to the correct page when pressed on)',
              type: 'string',
              validation: (Rule: {required: () => any}) => Rule.required(),
            },
            {
              name: 'number',
              title: 'Number in line',
              description:
                'The number in the sequence of applications this application should be shown',
              type: 'number',
              validation: (Rule: {required: () => any}) => Rule.required().min(1),
            },
            {
              name: 'img_description',
              title: 'Image description',
              description: 'The text under the images in the applications row',
              type: 'string',
            },
            {
              name: 'alt',
              title: 'Alternative text',
              description:
                'Text that appears if image doesnt load (you can set this to the name of the application on this image)',
              type: 'string',
            },
          ],
        },
      ],
      options: {
        layout: 'grid',
      },
    },
  ],
}
