import Image from "next/image";
import { urlFor } from "client";
import { aboutUs } from "types/sanity";
import populateBlockText from "app/functions/populateBlockText";

/**
 * @param params data passed from the About page which is queried in service.ts
 * @returns a DOM element containing the layout structure for the About page on the international market
 */

const About = ({ params }: { params: aboutUs }) => {
  return (
    <div className="w-[90vw] flex flex-col justify-center items-center py-10 border border-gray-400 rounded-md px-5 lg:px-10">
      <div className="w-full flex justify-center items-center flex-col lg:flex-row">
        <div className="relative w-full lg:w-1/2 h-96">
          <Image
            aria-labelledby="employee image"
            src={urlFor(params.image.asset._ref).url()}
            alt=""
            fill
            className="rounded-lg object-contain"
          />
        </div>
        <div aria-labelledby="employee details" className="w-full lg:w-1/2">
          <h2 className="font-bold text-xl lg:text-3xl py-5 lg:pt-0 lg:py-5">
            {params.title}
          </h2>
          {/* Loops to display the content from the "personal" block content from Sanity*/}
          {params.personal.map((el, index: number) =>
            el.children.map((line, i) => (
              <p className="text-lg lg:text-2xl" key={`${index}-${i}`}>
                {line.text}
              </p>
            ))
          )}
        </div>
      </div>
      {/* Runs the function that returns a correctly formatted block text */}
      {populateBlockText(params.company)}
    </div>
  );
};

export default About;
