// Converts the component to a client-side component to be able to use hooks
"use client";

import React from "react";
import { usePathname } from "next/navigation";
import Link from "next/link";
import { product } from "types/sanity";
import ImageCarousel from "./ImageCarousel";
import populateBlockText from "app/functions/populateBlockText";

/**
 * @param param data passed from the different [slug]-pages
 * @returns a DOM element containing the structure for the details-pages which is reused in all the [slug]-pages
 */

const Details = ({ params }: { params: product }) => {
  const pathname: string = usePathname(); // Uses one of the built in function in Next.js to get the current pathname

  /*
    Checks if the user is on the national market. It's not needed to get the baseUrl, because this component 
    is only used in pages with sub-routes after the country code in the URL
  */
  const isOnNationalMarket = pathname.includes(`/no/`);

  return (
    <div className="bg-background-texture w-[100vw]">
      <div className="grid grid-cols-2 lg:w-[90vw] mx-auto py-5 lg:py-10 gap-6 md:gap-10 items-center justify-items-center content-center  ">
        <div className="row-start-1 col-span-2 mx-auto text-center text-dark-text  h-full">
          <h1
            role="heading"
            aria-labelledby="ItemTitle"
            className="text-2xl lg:text-3xl xl:text-4xl font-extrabold text-center shadow-sm p-2 rounded-md"
          >
            {params.title}
          </h1>
        </div>
        <div className="row-start-2 col-span-2 w-[95vw] lg:w-full lg:col-span-1 h-full bg-gray-300 border border-black rounded-md ">
          <ImageCarousel params={params.images} />
        </div>
        <div className="row-start-4 w-[90vw] lg:w-full lg:row-start-2 col-span-2 lg:col-start-2 lg:col-span-1 p-5 lg:p-10 border border-black rounded-md bg-gray-100 h-full flex flex-col justify-start items-start text-left">
          <h2
            role="heading"
            aria-labelledby="SummaryTitle"
            className="font-semibold text-dark-text lg:pb-0 text-2xl lg:text-3xl"
          >
            {isOnNationalMarket ? "Sammendrag:" : "Summary:"}
          </h2>
          {/* Runs the function to generate the correct summary based on type from Sanity */}
          {populateBlockText(params.summary)}
        </div>
        <div className="row-start-3 lg:row-start-3 col-span-2 p-4 ">
          <Link
            aria-label="Navigate to contactform"
            href={isOnNationalMarket ? "no/kontakt" : "en/contact"}
            className="  bg-warning shadow-lg rounded-md text-center py-2 px-10 cursor-pointer border-2 items-center text-medium sm:text-xl 2xl:text-2xl font-semibold text-light-text"
          >
            {isOnNationalMarket ? "Send henvendelse" : "Send inquiry"}
          </Link>
        </div>
        {/* Only renders the details if there is content */}
        {params.details ? (
          <div className="row-start-5 w-[90vw] lg:w-full lg:row-start-4 col-start-1 col-span-2 mt-4 mb-5 border border-black rounded-md bg-gray-100 p-5 lg:p-10">
            <h2
              role="heading"
              aria-labelledby="DetailTitle"
              className="font-semibold text-dark-text  pb-2 text-2xl"
            >
              {isOnNationalMarket ? "Detaljer:" : "Details:"}
            </h2>
            <p className="font-normal text-lg lg:text-xl 2xl:text-2xl leading-relaxed	 ">
              {params.details}
            </p>
          </div>
        ) : (
          <></>
        )}
      </div>
    </div>
  );
};

export default Details;
