import React from "react";
import Image from "next/image";
import { urlFor } from "client";
import { images } from "types/sanity";
import Link from "next/link";

// Sets the type for the props
interface props {
  title: string;
  subtitle: string;
  images: images;
  base_path: string;
}

/**
 * @param props the props passed from the international homepage
 * @returns returns a row of images and descriptions
 */

const IntHomepageRow = (props: props) => {
  // Sorts the images based on the number-field
  const sortedImages = props.images.sort((a, b) => a.img_number - b.img_number);

  return (
    <div className="w-full border-t-2 bg-gray-100 mb-5 lg:mb-10 xl:mb-16">
      <div className="px-10 lg:pl-12 pt-10">
        <h1 className="font-bold text-2xl lg:text-3xl">{props.title}</h1>
        <h2 className="font-normal text-lg lg:text-2xl">{props.subtitle}</h2>
      </div>
      <div className="w-screen lg:px-10  py-5  flex items-center justify-center flex-col lg:flex-row">
        {sortedImages.map((image) => {
          return (
            <Link
              href={`${props.base_path}${image.slug}`}
              aria-label="NavigatableCard"
              className="w-4/5 flex justify-center items-center flex-col px-5 py-2 lg:py-0 lg:pt-5 h-64 lg:h-80 my-5 lg:my-0  lg:w-screen border-2 rounded-md border-slate-300 bg-slate-100  lg:mx-2  z-[60]"
            >
              <div className="h-3/5 relative w-full ">
                <Image
                  aria-labelledby="CardImage"
                  className="object-contain -z-40  "
                  src={urlFor(image.asset._ref).url()}
                  alt={image.alt}
                  fill
                />
              </div>
              <div className=" w-full text-center flex justify-center items-center  h-1/5 mt-5">
                <h3
                  role="heading"
                  aria-labelledby="TertiaryTitle"
                  className="text-lg lg:text-lg 2xl:text-2xl font-bold "
                >
                  {image["img_description"]}
                </h3>
              </div>
            </Link>
          );
        })}
      </div>
    </div>
  );
};

export default IntHomepageRow;
