"use client";

import { useCallback, useEffect, useMemo, useRef, useState } from "react";
import Select, { ActionMeta } from "react-select";
import countryList from "react-select-country-list";
import { CountryOption, EmailData } from "types/contactFormTypes";
import { getProductAndService } from "queries/service";
import emailjs from "@emailjs/browser";
import { product } from "types/sanity";
import ReCAPTCHA from "react-google-recaptcha";

const ContactForm = () => {
  const [visibleProductInput, setVisibleProductInput] =
    useState<boolean>(false);
  const [visibleServiceInput, setVisibleServiceInput] =
    useState<boolean>(false);
  const [manufacturerVisible, setManufacturerVisible] =
    useState<boolean>(false);

  const [productList, setProductList] = useState<string[]>([""]);
  const [serviceList, setServiceList] = useState<string[]>([""]);
  const [countryValue, setCountryValue] = useState<{
    value: string;
    label: string;
  } | null>({ value: "", label: "" });
  const CountryOptions = useMemo<CountryOption[]>(
    () => countryList().getData(),
    []
  );

  // States for handling whether or not the user can submit the form and if the message has been snet
  const [disabledSumbit, setDisabledSubmit] = useState<boolean>(true);
  const [isMessageSent, setMessageSent] = useState<boolean>(false);

  /* 
    A function that dynamically populates the lists 
    (currently not implemented, but it's left in the code for future improvements )
  */

  /*
  const populateLists = async () => {
    const grabbedData: product[] = await getProductAndService();
    const productTitles: string[] = [];
    const serviceTitles: string[] = [];
    grabbedData.map((element) => {
      element._type == "products"
        ? productTitles.push(element.title)
        : serviceTitles.push(element.title);
    });
    setProductList(productTitles);
    setServiceList(serviceTitles);
  };

  useEffect(() => {
    populateLists();
  }, []);
  */

  // Functions which keep track of which of the "annet" inputs that are active
  const checkProduct = (chk: string): void => {
    chk == "other"
      ? setVisibleProductInput(!visibleProductInput)
      : setVisibleProductInput(false);
  };
  const checkService = (chk: string): void => {
    chk == "other"
      ? setVisibleServiceInput(!visibleServiceInput)
      : setVisibleServiceInput(false);
  };
  const manufacturerSelected = (chk: string): void => {
    chk != "null"
      ? setManufacturerVisible(true)
      : setManufacturerVisible(false);
  };

  const handleCountry = async (
    newValue: CountryOption | null,
    _actionMeta: ActionMeta<CountryOption>
  ) => {
    setCountryValue(newValue);
    handleSubmit;
  };

  const handleSubmit = useCallback(
    async (e: React.FormEvent<HTMLFormElement>): Promise<void> => {
      e.preventDefault();
      const formData = new FormData(e.target as HTMLFormElement);
      if (countryValue?.label == "") return alert("Please select country");

      const name = (formData.get("firstName") +
        " " +
        formData.get("lastName")) as string;
      const email = formData.get("email") as string;
      const companyName = formData.get("companyName") as string;
      const companyPosition = formData.get("companyPosition") as string;
      const productOfInquiry = formData.get("productSelector") as string;
      const productDetails = formData.get("otherProduct") as string;
      const serviceOfInquiry = formData.get("serviceSelector") as string;
      const serviceDetails = formData.get("otherService") as string;
      const inquiryDetails = formData.get("inquiryDetails") as string;
      const country = countryValue?.label as string;
      const manufacturer = formData.get("semModel") as string;
      const modelNr = formData.get("modelNr") as string;

      const emailData: EmailData["data"] = {
        name: name,
        email: email,
        companyName: companyName,
        companyPosition: companyPosition,
        productOfInquiry: productOfInquiry,
        productDetails: productDetails,
        serviceOfInquiry: serviceOfInquiry,
        serviceDetails: serviceDetails,
        inquiryDetails: inquiryDetails,
        country: country,
        manufacturer: manufacturer,
        modelNr: modelNr,
      };

      // Initializes the emailJs client with the environment variables fetched from Vercel (.env on localhost)
      emailjs.init(process.env.NEXT_PUBLIC_EMAIL_JS_PUBLIC_KEY || "");

      /*
        Sends the email by using the built in function from the emailJs library. 
        We send three arguments, the two first specify which email template we want to use
        and the third is the data for the email as an object. 
      */
      emailjs
        .send(
          process.env.NEXT_PUBLIC_EMAIL_JS_SERVICE_ID || "",
          process.env.NEXT_PUBLIC_EMAIL_JS_TEMPLATE_ID || "",
          emailData
        )
        .then(
          function (response) {
            alert(
              "Thank you for your inquiry! We will respond to your message as soon as possible."
            );
            setMessageSent(true);
          },
          function (error) {
            alert("Error with sending inquiry: " + error);
          }
        );

      setDisabledSubmit(true);
    },
    [countryValue]
  );

  return (
    <form role="form" onSubmit={handleSubmit}>
      <div className="bg-light-bg border border-black rounded-md text-sm laptop:text-base md:w-[750px] lg:grid grid-cols-2 grid-rows-8 p-5  gap-y-1 flex flex-col">
        <div className="row-start-1 col-span-2 ml-1">
          <h1 className="text-xl lg:text-2xl underline underline-offset-4">
            Contact us
          </h1>
        </div>
        <div className="row-start-2 col-start-1 ml-1 inline-grid mt-2 gap-y-3">
          <label htmlFor="firstName" className="flex flex-col">
            First name: *
            <input
              required
              placeholder="John"
              type="text"
              name="firstName"
              id="firstNameInput"
              className="border border-gray-500 shadow-md bg-white rounded-md w-2/3 md:w-[200px] md:float-right md:ml-2 pl-1 py-1"
            />
          </label>
          <label htmlFor="lastName" className="flex flex-col">
            Last name: *
            <input
              required
              placeholder="Doe"
              type="text"
              name="lastName"
              id="lastNameInput"
              className="border border-gray-500 shadow-md bg-white rounded-md w-2/3 md:w-[200px] md:float-right md:ml-2 pl-1 py-1"
            />
          </label>
          <label htmlFor="email" className="flex flex-col">
            Email: *
            <input
              required
              placeholder="johnDoe@gmail.com"
              type="text"
              name="email"
              id="emailInput"
              className="border border-gray-500 shadow-md bg-white rounded-md w-2/3 md:w-[200px] md:float-right md:ml-2 pl-1 py-1"
            />
          </label>
        </div>
        <div className="relative row-start-3 md:row-start-4 col-start-1 ml-1 inline-grid my-4 gap-y-3 top-4 md:top-2">
          <label htmlFor="companyName" className="flex flex-col">
            Company name: *
            <input
              required
              placeholder="John Doe Limited"
              type="text"
              name="companyName"
              id="companyNameInput"
              className="border border-gray-500 shadow-md bg-white rounded-md w-[145px] md:w-[200px] md:float-right md:ml-2 pl-1 py-1"
            />
          </label>
          <label htmlFor="companyPosition" className="flex flex-col">
            Company position:
            <input
              type="text"
              placeholder="CEO"
              name="companyPosition"
              id="companyPositionInput"
              className="border border-gray-500 shadow-md bg-white rounded-md w-[145px] md:w-[200px] md:float-right md:ml-2 pl-1 py-1"
            />
          </label>
          <label htmlFor="country" className="flex flex-col">
            Country:
            <Select
              options={CountryOptions}
              value={countryValue}
              onChange={handleCountry}
              className={
                "border border-gray-500 shadow-md bg-white rounded-md w-[145px] md:w-[200px] md:float-right md:ml-2"
              }
            />
          </label>
        </div>
        <div className="row-start-6 col-span-2 md:col-span-1 col-start-1 md:mt-2 md:inline-grid">
          <label htmlFor="inquiryDetails" className="">
            Details about your inquiry
          </label>
          <textarea
            name="inquiryDetails"
            id="inquiryDetailsInput"
            cols={100}
            rows={4}
            placeholder="Insert details here"
            className="col-start-1 border border-gray-500 shadow-md bg-white w-[300px] md:w-2/3 px-2 mx-1 rounded-md"
          />
        </div>
        <div className="row-start-2 md:row-span-2 col-start-2 text-left mt-2 flex flex-col pl-1">
          <label htmlFor="inquiryProduct" className="px-px">
            Select relevant product of inquiry
          </label>
          <select
            name="productSelector"
            id="productSelector"
            onChange={(e) => checkProduct(e.target.value)}
            className="border border-gray-500 shadow-md bg-white rounded-md w-2/3 py-1 md:w-32 text-center my-2 md:ml-12 "
          >
            <option value="null">Product</option>
            {/*
              {productList.map(title => (
              <option key={productList.indexOf(title)} value={title}>{title}</option>
              ))}
              */}
            <option value="NICE">NICE&trade; (table top EBSD detector)</option>
            <option value="NICE">NICE (small chamber EBSD detector)</option>
            <option value="UF-420">UF-420 (medium speed detector)</option>
            <option value="UF-1100">UF-1100 (high speed detector)</option>
            <option value="HR4M">HR4M (high pixel resolution detector)</option>
            <option value="other">other</option>
          </select>
          {visibleProductInput && (
            <textarea
              aria-label="Product details"
              name="otherProduct"
              id="otherProductInput"
              cols={100}
              rows={2}
              placeholder="Details about other product"
              className="col-start-1 border border-gray-500 shadow-md bg-white w-40 md:w-[300px] px-2 mx-1 rounded-md"
            />
          )}
        </div>
        <div className="row-start-3 md:row-start-4 md:row-span-2 col-start-2 text-left mt-2 flex flex-col pl-1">
          <label htmlFor="inquiryService" className="px-1">
            Select relevant service of inquiry
          </label>
          <select
            name="serviceSelector"
            id="serviceSelector"
            onChange={(e) => checkService(e.target.value)}
            className="rounded-md w-2/3 py-1 md:w-32 text-center  my-2 md:ml-12 border border-gray-500 shadow-md bg-white"
          >
            <option value="null">Service</option>
            {/*
              {serviceList.map(title => (
                <option key={serviceList.indexOf(title)} value={title}>{title}</option>
              ))}
              */}
            <option value="PC upgrade">PC upgrade</option>
            <option value="NORDIF detector overhaul/service">
              NORDIF detector overhaul/service
            </option>
            <option value="Camera upgrade">Camera upgrade</option>
            <option value="Detector transfer to new SEM">
              Detector transfer to new SEM
            </option>
            <option value="Detector service contract">
              Detector service contract
            </option>
            <option value="other">OTHER</option>
          </select>
          {visibleServiceInput && (
            <textarea
              aria-label="Service details"
              name="otherService"
              id="otherServiceInput"
              cols={100}
              rows={2}
              placeholder="Details about other service"
              className="col-start-2 border border-gray-500 shadow-md bg-white w-40 md:w-[300px] px-2 mx-1 rounded-md"
            />
          )}
        </div>

        <div className="row-start-4 md:row-start-6 col-start-2 text-left flex flex-col pl-1">
          <label htmlFor="semModel" className="px-px">
            SEM manufacturer and model number:
          </label>
          <select
            name="semModel"
            id="semModel"
            onChange={(e) => manufacturerSelected(e.target.value)}
            className="rounded-md w-2/3 py-1 md:w-32 text-center my-2 md:ml-12 border border-gray-500 shadow-md bg-white"
          >
            <option value="null">Manufacturer</option>
            {/*
              {manufacturers.map(manufacturer => (
                <option value={manufacturer.title} key={manufacturers.indexOf(manufacturer)}>{manufacturer.title}</option>
              ))}
              */}
            <option value="Hitachi">Hitachi</option>
            <option value="Jeol">Jeol</option>
            <option value="Tescan">Tescan</option>
            <option value="Thermo Fisher">Thermo Fisher (FEI/Philips)</option>
            <option value="Zeiss">Zeiss</option>
            <option value="Coxem">Coxem</option>
            <option value="EMcrafts">EMcrafts</option>
            <option value="Hirox">Hirox</option>
            <option value="Pemtron">Pemtron</option>
            <option value="SEC">SEC</option>
            <option value="other">OTHER</option>
          </select>
          {manufacturerVisible && (
            <textarea
              aria-label="Manufacturer details"
              name="modelNr"
              id="modelNrInput"
              cols={100}
              rows={2}
              placeholder="SEM model number"
              className="col-start-1 border border-gray-500 shadow-md bg-white w-40 md:w-[300px] px-2 mx-1 rounded-md"
            />
          )}
        </div>
        <div className="row-start-7 col-span-2 md:col-span-1 col-start-1 md:mt-2 md:inline-grid">
          {/*
              Imported component that checks that the user is a human an not a robot. 
              This is done by checking a box. The "onChange" listener will be triggered
              when a valid user is verified, which in return lets the user send the form
              by enabling the send button, by changing the state. 
          */}
          <ReCAPTCHA
            sitekey={process.env.NEXT_PUBLIC_GOOGLE_RECAPTCHA_SITE_KEY || ""}
            onChange={() => setDisabledSubmit(false)}
          />
        </div>
        <div className="row-start-8 col-start-2 mt-2 ml-1">
          <button
            aria-label="Submitted form"
            disabled={disabledSumbit}
            type="submit"
            className={`${
              disabledSumbit ? "bg-submit/50" : "bg-submit"
            } w-2/3 md:w-[345px] rounded-md text-center py-2 px-2 shadow-lg`}
          >
            <span className="text-xl font-semibold text-light-text">
              {isMessageSent ? "Sent!" : "Send inquiry"}
            </span>
          </button>
        </div>
      </div>
    </form>
  );
};

export default ContactForm;
