import { urlFor } from "client";
import Image from "next/image";
import React from "react";
import { image } from "types/sanity";

interface props {
  firstDetail: string;
  secondDetail: string;
  image: image;
  reverse: boolean;
}

/**
 * @param props The props passed from the national homepage, fetched from the "Hjemmeside"-type from Sanity
 * @returns returns a row of images and description
 */

const NatHomePageRow = (props: props) => {
  return (
    <>
      <div
        className={`flex flex-col w-screen lg:w-4/5 lg:h-[60vh] text-2xl gap-6 lg:gap-10 ${
          props.reverse ? "lg:flex-row-reverse" : "lg:flex-row"
        }`}
      >
        <div className="w-4/5 h-full self-center lg:w-1/2 flex justify-center items-center lg:py-5 ">
          <ul
            role="list"
            aria-labelledby="CardList"
            className=" h-full w-full flex flex-col justify-evenly items-center gap-4 text-center lg:text-left text-lg lg:text-xl 2xl:text-3xl"
          >
            <li className="border-2 h-1/3 p-3 lg:p-2 border-gray-400 rounded-md flex justify-center items-center  text-center  bg-white">
              {props.firstDetail}
            </li>
            <li className="border-2 h-1/3 p-3 lg:p-2 border-gray-400 rounded-md flex justify-center items-center text-center bg-white">
              {props.secondDetail}
            </li>
          </ul>
        </div>
        <div className="flex justify-center items-center h-64 lg:h-[50vh] relative w-4/5 self-center lg:w-1/2 z-[60]">
          <Image
            aria-labelledby="CardImage"
            className="object-contain -z-40 "
            src={urlFor(props.image.asset._ref).url() || ""}
            alt={props.image.alt}
            fill
          />
        </div>
      </div>
    </>
  );
};

export default NatHomePageRow;
