import Image from "next/image";
import { urlFor } from "client";
import { omOss } from "types/sanity";

/**
 * @param params The parameter fetched and passed from the omOss page
 * @returns A component used for layout shown in the omOss page on the national market
 */

const OmOss = ({ params }: { params: omOss }) => {
  return (
    <div className="bg-slate-100 py-5 lg:p-16 my-10 rounded-md border border-gray-400 px-5 flex flex-col lg:flex-row justify-center items-center gap-4 lg:gap-10">
      <div className="w-full lg:w-1/2  self-center lg:self-start rounded-md">
        <div className="w-full h-[50vh] relative rounded-md border border-gray-400 bg-white">
          <Image
            className="object-contain"
            aria-labelledby="EmployeeImage"
            src={urlFor(params.image.asset._ref).url()}
            alt={params.image.alt}
            fill
          />
        </div>
      </div>
      <div aria-labelledby="EmployeeDetails" className="lg:w-1/2 ">
        <h2 className="text-xl lg:text-2xl xl:text-3xl font-bold pb-5">
          {params.title}
        </h2>
        {params.personal.map((el, index: number) =>
          el.children.map((line, i) => (
            <p
              aria-labelledby="EmployeeDataRow"
              className="lg:text-lg xl:text-xl"
              key={`${index}-${i}`}
            >
              {line.text}
            </p>
          ))
        )}
      </div>
    </div>
  );
};

export default OmOss;
