import About from "app/components/About";
import DefaultContainer from "app/components/DefaultContainer";
import { Metadata } from "next";
import { getItemsByType } from "queries/service";
import { Key } from "react";
import { aboutUs } from "types/sanity";

// Exports a built in const that sets when the content of the page should revalidate, and if outdated refetched. In seconds so 3600 equals one hour
export const revalidate = 3600;

/**
 * Exports a built in function that dynamically generates the metadata for this page.
 * Because we are using the revalidate, and because Next automatically "dedupes" the requests to sanity we can run the same query multiple times without casuing many request
 */
export async function generateMetadata(): Promise<Metadata> {
  const about: aboutUs[] = await getItemsByType("about");

  return {
    title: about[0].title,
    description: about[0].personal[0].children[0].text,
  };
}

/**
 * @returns The About page for the international market
 */

const page = async () => {
  // Fetching all the elements with the type "about" from the Sanity db
  const about: aboutUs[] = await getItemsByType("about");

  return (
    // Uses a default container to easily center the data
    <DefaultContainer>
      <div className="flex justify-center items-center flex-col :w-[90vw] self-center">
        <div className="w-full pb-5">
          <h1 className="text-3xl lg:text-4xl font-bold  underline decoration-1	 underline-offset-4">
            About us:
          </h1>
        </div>
        <div className="bg-slate-100  flex justify-center items-center flex-col   rounded-md w-full">
          {about.map((about, index) => {
            return <About key={index} params={about} />;
          })}
        </div>
      </div>
    </DefaultContainer>
  );
};

export default page;
