import React from "react";
import { Metadata } from "next";
import Image from "next/image";
import { getItemsByType } from "queries/service";
import IntHomepageRow from "app/components/IntHomepageRow";
import { urlFor } from "client";
import { homePage } from "types/sanity";

/**Exports a built in function that generates the metadata for this page. */
export async function generateMetadata(): Promise<Metadata> {
  return {
    title: "Homepage for the international market",
    description:
      "Electron Backscatter Diffraction - EBSD. EBSD detector systems",
  };
}

/**
 * @returns The homepage for the international market
 */
const page = async () => {
  /* 
    Fetches the data for the type "homepage" and sets it to the first element in the response, 
    because it returns an array, but we only want the first element, because we only have one page 
  */
  const dataList: homePage[] = await getItemsByType("homepage");
  const data = dataList[0];

  return (
    <div className="w-screen flex justify-center items-center flex-col text-dark-text bg-background-texture">
      <div className=" w-full lg:py-10">
        <div className="flex justify-center items-center h-56 lg:h-96 w-full  relative">
          <Image
            className=" object-contain "
            src={urlFor(data["main_image"].asset._ref).url()}
            alt={data["main_image"].alt}
            fill
            priority
          />
        </div>
      </div>
      <IntHomepageRow
        title={data["title_detectors"]}
        subtitle={data["subtitle_detectors"]}
        images={data["images_detectors"]}
        base_path={"en/products/"}
      />
      <IntHomepageRow
        title={data["title_services"]}
        subtitle={data["subtitle_services"]}
        images={data["images_services"]}
        base_path={"en/services/"}
      />
      <IntHomepageRow
        title={data["title_applications"]}
        subtitle={data["subtitle_applications"]}
        images={data["images_applications"]}
        base_path={"en/applications/"}
      />
    </div>
  );
};

export default page;
