import { omOss } from "types/sanity";
import OmOss from "app/components/OmOss";
import { getItemsByType } from "queries/service";
import { Metadata } from "next";

// Exports a built in const that sets when the content of the page should revalidate, and if outdated refetched. In seconds so 3600 equals one hour
export const revalidate = 3600;

/**Exports the built in function that can be used in combination with dynamic route segments to statically generate routes at build time instead of on-demand at request time. */
export async function generateMetadata(): Promise<Metadata> {
  const omOss: omOss[] = await getItemsByType("omOss");

  return {
    title: omOss[0].title,
    description: omOss[0].personal[0].children[0].text,
  };
}

/**
 * @returns The About page for the international market
 */

const page = async () => {
  // Fetching all the elements with the type "omOss" from the Sanity db
  const omOss: omOss[] = await getItemsByType("omOss");
  return (
    <div className="bg-light-bg flex justify-center items-center flex-col w-screen self-center">
      <div className="w-[90vw] lg:w-2/3">
        <div className="w-full">
          <h1 className="text-3xl lg:text-4xl xl:text-5xl font-bold text-black mt-10 underline decoration-1	 underline-offset-4">
            Om oss
          </h1>
        </div>
        {omOss.map((omOss, index) => {
          return <OmOss key={index} params={omOss} />;
        })}
      </div>
    </div>
  );
};

export default page;
