import {
  getNationalSitemapData,
  getInterationalSitemapData,
} from "queries/service";

//Exports the built in sitemap function that generates the xml-file which is used so that Google more easily can detect new content and crawl the website more efficiently
export default async function sitemap() {
  // Fetches the respective data for the two markets
  const nationalData = await getNationalSitemapData();
  const internationalData = await getInterationalSitemapData();

  // Sets the dynamic paths for the national market
  const dynamicNationalPaths = nationalData.map((category) => ({
    url: `https://www.nordif.com/no/${category._type}/${category.slug}`,
    lastModified: new Date().toISOString(),
  }));

  // Sets the dynamic paths for the international market
  const dynamicInternationalPaths = internationalData.map((category) => ({
    url: `https://www.nordif.com/en/${category._type}/${category.slug}`,
    lastModified: new Date().toISOString(),
  }));

  // Sets the static routes
  const staticRoutes = [
    "/en",
    "/en/about",
    "/en/contact",
    "/en/products",
    "/no",
    "/no/kontakt",
    "/no/omOss",
  ].map((route) => ({
    url: `https://www.nordif.com${route}`,
    lastModified: new Date().toISOString(),
  }));

  // Returns an array with all the respective data for the dynamic and static data for both the national and international market
  return [
    ...dynamicNationalPaths,
    ...dynamicInternationalPaths,
    ...staticRoutes,
  ];
}
