import { NextResponse } from "next/server";
import type { NextRequest } from "next/server";

/**
 * @returns The built in middleware function which redirects the user to the correct market based on the country code from their request header. Uses the built in NextRequest
 */
export function middleware(request: NextRequest) {
  // If the user is on development mode it will automaticall redirect the user to the national market, simply because it cannot detect the country from localhost
  if (process.env.NODE_ENV === "development") {
    const url = request.nextUrl.clone();
    url.pathname = "/no";
    return NextResponse.redirect(url);
  } else {
    // If the user is not in development and currently located in Norway (The ISO code for Norway is 'NO') it will redirect to the national homepage
    if (request.geo?.country === "NO") {
      const url = request.nextUrl.clone();
      url.pathname = "/no";
      return NextResponse.redirect(url);
    }
    // If the user is not in development and currently NOT located in Norway it will redirect to the international homepage
    else {
      const url = request.nextUrl.clone();
      url.pathname = "/en";
      return NextResponse.redirect(url);
    }
  }
}

// This is reserved const name which tells the page when it should run, in this case it should only run when the user navigates to "nordif.com" and not eg. "nordif.com/no" or "nordif.com/en"
export const config = {
  matcher: "/",
};
