// Imports the Sanity client
import client from "client";
import { headerItems, product } from "types/sanity";

// Retrieves all the items with the type used as parameter
export async function getItemsByType(type: string) {
  const data: any = await client.fetch(
    `*[_type == '${type}'] | order(number asc)`
  );
  return data;
}

// Retrieves the item with the slug used as parameter
export async function getItemBySlug(slug: string) {
  const data: any = await client.fetch(`*[slug == '${slug}']`);
  return data;
}

// Retrieves the data that is used in the national header, sorted by the number and the _type
export async function getNationalHeaderItems() {
  const data: headerItems = await client.fetch(
    `[
      {
        "Tjenester": *[_type == "tjenester"]{_type, title, slug, number} | order(number asc) | order(_type),
        "Analyser": *[_type == "analyser"]{_type, title, slug, number} | order(number asc) | order(_type),
        "OmOss": *[_type == "omOss"]{_type, title, slug, number} | order(number asc) | order(_type),
        "Produkter": *[_type == "products"]{_type, title, slug, number} | order(number asc) | order(_type)
      }
    ]`
  );

  return data;
}

// Retrieves the data that is used in the international header, sorted by the number and the _type
export async function getInternationalHeaderItems() {
  const data: headerItems = await client.fetch(
    `[
      {
        "Products": *[_type == "products"]{_type, title, slug, number} | order(number asc) | order(_type),
        "Services": *[_type == "services"]{_type, title, slug, number} | order(number asc) | order(_type),
        "Applications": *[_type == "applications"]{_type, title, slug, number} | order(number asc) | order(_type)
      }
    ]`
  );

  return data;
}

// Retrieves the data used in the national contactform
export function getAnalyserOgTjenster() {
  const data: Promise<product[]> = client.fetch(
    `*[_type == 'semAnalyser' && _type == 'tjenester']`
  );

  return data;
}

// Retrieves the data used in the international contactform
export function getProductAndService() {
  const data: Promise<product[]> = client.fetch(
    `*[_type == 'products' && _type == 'services']`
  );

  return data;
}

// Retrieves the data for the static paths in the national market
export function getNationalSitemapData() {
  const data: Promise<product[]> = client.fetch(
    `*[_type == 'analyser' || _type == 'tjenester'] | order(_type)`
  );

  return data;
}

// Retrieves the data for the static paths in the international market
export function getInterationalSitemapData() {
  const data: Promise<product[]> = client.fetch(
    `*[_type == 'applications' || _type == 'products' || _type == 'services'] | order(_type)`
  );

  return data;
}
