/**
 * @interface baseSanity is the base for every sanity object used
 */
interface baseSanity {
  /** @member _id id of sanity object*/
  _id: string;

  /** @member _type the database "table" the object originates from*/
  _type: string;

  /** @member title title of object*/
  title: string;

  /** @member slug url slug of object */
  slug: string;
}
/**
 * @interface product is a database element of the tables: products, analyser, tjenester, services, and applications
 */
export interface product extends baseSanity {
  /**@member details - goes into more details about the product than the summary */
  details: string;

  /**@member summary - gives a short rundown of the products capabilities */
  summary: [
    {
      listItem: string;
      _key: string;
      _type: string;
      style: string;
      level: number;
      children: children;
      style: string;
    }
  ];

  /**@interface images - includes images of, or related to the product */
  images: images;
}
/**
 * @aboutUs is an interface for the table elements
 */
export interface aboutUs extends baseSanity {
  personal: [
    {
      _key: string;
      _type: string;
      style: string;
      children: children;
    }
  ];
  company: {
    _key: string;
    _type: string;
    style: string;
    level: number;
    children: children;
    listItem: string;
  }[];
  image: image;
}
export interface omOss extends baseSanity {
  number: number;
  personal: [
    {
      _key: string;
      _type: string;
      style: string;
      level: number;
      children: children;
    }
  ];
  image: image;
}
export interface homePage {
  _id: string;
  _type: string;
  main_image: image;
  title_services: string;
  subtitle_services: string;
  images_services: images;
  title_detectors: string;
  subtitle_detectors: string;
  images_detectors: images;
  title_applications: string;
  subtitle_applications: string;
  images_applications: images;  
}
export interface hjemmeside extends baseSanity{
  details_1: string;
  details_2: string;
  details_3: string;
  details_4: string;
  keywords: {
    _key: string;
    _type: string;
    style: string;
    listItem: string;
    children: children;
    level: number;
  }[];
  image1: image;
  image2: image;
  second_title: string;
  images: images;
}
/**@interface image is an image object */
export interface image {
  img_number: number;
  slug: string | undefined;
  _key: string;
  alt: string;
  img_description: string;
  asset: {
    _ref: string;
  };
}
/**
 * @interface images is an array of images objects, NOT image objects
 */
export type images = {
  /**@label _key - used to declare item within other DOM elements */
  _key: string;
  /**@label alt - alt text for SEO and accessability */
  alt: string;
  /**@label img_description - additional text related to image */
  img_description: string;
  /**@label img_number - what order the image is supposed to be rendered */
  img_number: number;
  /**@label asset - includes the image elements assets */
  slug: string | undefined;
  asset: {
    /**@label _ref - image reference */
    _ref: string;
    /**@label _type - type of image, should always be "image" */
    _type: string;
  };
}[];
/**@type children is an array of objects holding lines of text */
export type children = [
  {
    /**@member _key used to declare item withing other DOM elements */
    _key: string;

    /**@member _type defines what the text should be interpreted as, f.eks: bullet or string */
    _type: string;

    /**@member text is a string */
    text: string;
  }
];
export interface navigationData {
  _type: string;
  title: string;
  slug: string;
  number: number;
}
[];
/**
 * @interface intHomePageRow interface for natHomePageRow
 */
export interface intHomePageRow {
  /**@label */
  title_detectors: string;
  /**@label */
  subtitle_detectors: string;
  /**@label */
  images_detectors: {
    _type: string;
    alt: string;
    _key: string;
    asset: {
      _ref: string;
      _type: string;
    };
    slug: string | undefined;
    img_number: number;
    img_description: string;
  }[];
}
/**
 * @interface natHomePageRow interface for natHomePageRow
 */
export interface natHomePageRow {
  /**@label first detail of natHomePageRow */
  firstDetail: string;
  /**@label second detail of natHomePageRow */
  secondDetail: string;
  /**@prop image of natHomePageRow */
  image: image;
  /**@label reverse is a boolean*/
  reverse: boolean;
}
/**@interface headerItems - holds data for headerItems */
export interface headerItems {
  /**@label slug - is the url-slug of the headerItem */
  slug: string;
  /**@label number - is the order in which the headerItem should be rendered */
  number: number;
  /**@label _type - defines the type of the headerItem */
  _type: string;
  /**@label title - the title of the headerItem */
  title: string;
}
[];
